@@ -1,3 +1,4 @@
+import platform
 import sys
 from argparse import ArgumentTypeError
 from collections import defaultdict
@@ -126,13 +127,22 @@ def list_project(path):
 # -- create related commands -------------------------------------------
 
 def create_project(project_path, class_names_colors, images,
+                   annotations_json_func=None,
                    remove_default_classes=False, force_write=False):
     """create a qupath project"""
     from paquo.classes import QuPathPathClass
+    from paquo.images import QuPathImageType
     from paquo.projects import QuPathProject
+    from paquo._logging import get_logger
+    from paquo._utils import load_json_from_path
+
+    _logger = get_logger(__name__)
 
     mode = 'x' if not force_write else 'w'
 
+    if annotations_json_func is not None and not callable(annotations_json_func):
+        raise ValueError("annotations_json_func should be callable")
+
     # noinspection PyTypeChecker
     with QuPathProject(project_path, mode=mode) as qp:
         if remove_default_classes:
@@ -145,7 +155,14 @@ def create_project(project_path, class_names_colors, images,
         qp.path_classes = path_classes
 
         for image in images:
-            qp.add_image(image)
+            qp_image = qp.add_image(image, image_type=QuPathImageType.BRIGHTFIELD_H_E)
+
+            if annotations_json_func:
+                annotations_jsons = annotations_json_func(Path(image).name)
+                for annotations_json in annotations_jsons:
+                    _logger.info(f"loading '{annotations_json}'")
+                    geojson = load_json_from_path(annotations_json)
+                    qp_image.hierarchy.load_geojson(geojson["annotations"])
 
         name = qp.name
     return name
@@ -165,3 +182,78 @@ def export_annotations(path, image_idx, pretty=False):
             pprint.pprint(data)
         else:
             print(data)
+
+
+# -- open related commands ------------------------------------------
+
+def open_qupath(project_path):
+    """launch qupath with the provided project"""
+    import subprocess
+    from zipfile import ZipFile
+    from contextlib import contextmanager, ExitStack
+    from tempfile import TemporaryDirectory
+    from paquo._config import settings, to_kwargs
+    from paquo.jpype_backend import find_qupath
+
+    # retrieve the path of the qupath executable
+    app_dir, _, _, _ = find_qupath(**to_kwargs(settings))
+    system = platform.system()
+    if system == "Linux":
+        qupath, = Path(app_dir).parent.parent.joinpath("bin").glob("QuPath-*")
+
+    elif system == "Darwin":
+        qupath, = Path(app_dir).parent.joinpath("MacOS").glob("QuPath-*")
+
+    elif system == "Windows":
+        _qp_exes = list(Path(app_dir).parent.glob("QuPath-*.exe"))
+        assert len(_qp_exes) == 2, f"this should have returned two paths, got {_qp_exes}"
+        qupath, = (qp for qp in _qp_exes if "console" in qp.stem)
+
+    else:
+        raise ValueError(f"Unknown platform {system}")
+
+    @contextmanager
+    def prepare_dir(path: Path):
+        # unzip a qpzip file to a temporary directory
+        if path.is_file() and path.suffix == ".qpzip":
+            with ExitStack() as stack:
+                tmp_path = stack.enter_context(
+                    TemporaryDirectory(prefix="pado", suffix="qpzip")
+                )
+                with ZipFile(path) as qpzip:
+                    qpzip.extractall(tmp_path)
+                print(f"Extracted qpzip to {tmp_path}")
+                yield Path(tmp_path)
+                # dont clean up tmp if no errors were raised
+                stack.pop_all()
+        else:
+            yield path
+
+    with prepare_dir(Path(project_path)) as p:
+        if p.is_dir():
+            p /= "project.qpproj"
+        if not (p.is_file() and p.suffix == ".qpproj"):
+            raise ValueError(f"Not a qupath project: '{p}'")
+
+        subprocess.run([qupath, '-p', p.resolve()])
+
+
+# -- quzip related commands -------------------------------------------
+
+def qpzip_project(project_path):
+    """create a zip archive of a qupath project that can be used with `paquo open`"""
+    import shutil
+    from tempfile import TemporaryDirectory
+
+    p = Path(project_path).expanduser().absolute()
+    if p.is_dir():
+        p /= "project.qpproj"
+    if not (p.is_file() and p.suffix == ".qpproj"):
+        raise ValueError(f"Not a qupath project: '{p}'")
+
+    project_path = p.parent
+    with TemporaryDirectory() as tmpdir:
+        tmp_base_name = Path(tmpdir) / project_path.name
+        tmp_zip = shutil.make_archive(tmp_base_name, "zip", root_dir=project_path, base_dir=".")
+        qpzip = shutil.move(tmp_zip, project_path.with_suffix(".qpzip"))
+    print(f"created: {qpzip}")
