@@ -149,7 +149,7 @@ class SimpleURIImageProvider:
 
         def __repr__(self):  # pragma: no cover
             p = Path(self)
-            return f'<FilenamePathId("{p.name}") @ "{p.parent}">'
+            return f'FilenamePathId("{p.name}", parent="{p.parent}")'
 
     class URIString(str):
         """string uri's can differ in their string representation and still be identical"""
@@ -285,7 +285,7 @@ class _ProjectImageEntryMetadata(MutableMapping):
         self._entry.clearMetadata()
 
     def __repr__(self):
-        return f"<Metadata({repr(dict(self))})>"
+        return f"Metadata({repr(dict(self))})"
 
 
 class _ImageDataProperties(MutableMapping):
@@ -334,7 +334,7 @@ class _ImageDataProperties(MutableMapping):
         return iter(map(str, dict(self._image_data.getProperties())))
 
     def __repr__(self):
-        return f"<Properties({repr(dict(self))})>"
+        return f"Properties({repr(dict(self))})"
 
 
 # note: this could just be autogenerated by inspecting the ImageType
@@ -393,20 +393,20 @@ class QuPathProjectImageEntry(QuPathBase[DefaultProjectImageEntry]):
 
     @cached_property
     def _image_data(self):
-        try:
-            with redirect(stdout=True, stderr=True):
-                return self.java_object.readImageData()
-        # from java land
-        except IOException:  # pragma: no cover
-            image_data_fn = self.entry_path / "data.qpdata"
+        with redirect(stdout=True, stderr=True):
             try:
-                image_data = PathIO.readImageData(
-                    File(str(image_data_fn)),
-                    None, None, BufferedImage
-                )
-            except FileNotFoundException:
-                raise FileNotFoundError("image_data missing")
-            return image_data
+                return self.java_object.readImageData()
+            # from java land
+            except IOException:  # pragma: no cover
+                image_data_fn = self.entry_path / "data.qpdata"
+                try:
+                    image_data = PathIO.readImageData(
+                        File(str(image_data_fn)),
+                        None, None, BufferedImage
+                    )
+                except FileNotFoundException:
+                    raise FileNotFoundError("image_data missing")
+                return image_data
 
     @cached_property
     def _properties(self):
@@ -554,7 +554,7 @@ class QuPathProjectImageEntry(QuPathBase[DefaultProjectImageEntry]):
             return QuPathPathObjectHierarchy(self.java_object.readHierarchy(), _image_ref=self)
 
     def __repr__(self):
-        return f"<ImageEntry image_name='{self.image_name}'>"
+        return f"ImageEntry(image_name='{self.image_name}')"
 
     def _repr_html_(self, compact=False, index=0):
         from base64 import b64encode
