@@ -77,7 +77,7 @@ class _ProjectImageEntriesProxy(collections_abc.Sequence):
         return len(self._images)
 
     def __repr__(self):
-        return f"<ImageEntries({repr([entry.image_name for entry in self])})>"
+        return f"ImageEntries({repr([entry.image_name for entry in self])})"
 
     def _repr_html_(self, compact=False) -> str:
         from paquo._repr import div, h4, repr_html
@@ -202,14 +202,16 @@ class QuPathProject(QuPathBase[DefaultProject]):
             _exists = False
 
         if _exists:
-            project = ProjectIO.loadProject(File(str(p)), BufferedImage)
+            with redirect(stderr=True, stdout=True):
+                project = ProjectIO.loadProject(File(str(p)), BufferedImage)
         else:
             p_dir = p.parent
             p_dir.mkdir(parents=True, exist_ok=True)
             for f in p_dir.iterdir():
                 if not f.match("*.backup"):
                     raise ValueError("will only create projects in empty directories")
-            project = Projects.createProject(File(str(p_dir)), BufferedImage)
+            with redirect(stderr=True, stdout=True):
+                project = Projects.createProject(File(str(p_dir)), BufferedImage)
 
         super().__init__(project)
         self._image_entries_proxy = _ProjectImageEntriesProxy(self)
@@ -411,7 +413,7 @@ class QuPathProject(QuPathBase[DefaultProject]):
 
     def __repr__(self) -> str:
         # name = self.java_object.getNameFromURI(self.java_object.getURI())
-        return f"<QuPathProject path='{self._path}' mode='{self._mode}'>"
+        return f'{type(self).__name__}(path="{self._path}" mode="{self._mode}")'
 
     def _repr_html_(self) -> str:
         from paquo._repr import br, h3, div, p, span, repr_html
